@@ -2,16 +2,16 @@
 api provides all the classes which manage access to runZero http resources and endpoints
 """
 
-from .admin import CustomSourcesAdmin, OrgsAdmin
-from .asset_data_sources import CustomSources
+from .admin import CustomIntegrationsAdmin, OrgsAdmin
+from .custom_integrations import CustomIntegrations
 from .imports import CustomAssets
 from .sites import Sites
 from .tasks import Tasks
 
 __all__ = [
     "CustomAssets",
-    "CustomSources",
-    "CustomSourcesAdmin",
+    "CustomIntegrations",
+    "CustomIntegrationsAdmin",
     "OrgsAdmin",
     "Sites",
     "Tasks",
